@@ -27,8 +27,8 @@ do_open_action() {
 
     case "${filetype}" in
     html)
-        (if [ -n "" -a  -n "$DISPLAY" ]; then
-            ( file://"${MC_EXT_CURRENTDIR}"/"${MC_EXT_BASENAME}" &) 1>&2
+        (if [ -n "konqueror" -a  -n "$DISPLAY" ]; then
+            (konqueror file://"${MC_EXT_CURRENTDIR}"/"${MC_EXT_BASENAME}" &) 1>&2
         else
             elinks "${MC_EXT_FILENAME}" || \
                 links "${MC_EXT_FILENAME}" || \
@@ -46,7 +46,7 @@ view)
     do_view_action "${filetype}"
     ;;
 open)
-    "${MC_XDG_OPEN}" "${MC_EXT_FILENAME}" 2>/dev/null || \
+    ("${MC_XDG_OPEN}" "${MC_EXT_FILENAME}" >/dev/null 2>&1) || \
         do_open_action "${filetype}"
     ;;
 *)
